# OpenTelemetry Local Root Span Attributes

Progressively adds attributes defined by the
[HTTP Server Semantic Convention](https://opentelemetry.io/docs/specs/semconv/http/http-spans/#http-server-semantic-conventions)
to the OpenTelemetry local root span at key points in the request-response cycle.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/otlrs).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/otlrs).


## Requirements

This module requires the OpenTelemetry API library:

- [OpenTelemetry API](https://github.com/opentelemetry-php/api)


## Recommended libraries

This module doesn't do anything outside an OpenTelemetry context. The
OpenTelemetry SDK provides various ways on how a context can be created and
propagated throughout an application.

- [OpenTelemetry SDK](https://github.com/opentelemetry-php/api)
  - [Zero-code instrumentation](https://opentelemetry.io/docs/zero-code/php/)
  - [SDK Autoloading](https://opentelemetry.io/docs/languages/php/sdk/#autoloading)

The Drupal [OpenTelemetry SDK](https://www.drupal.org/project/otsdk) integration
module provides a straight forward way to configure and autoload the OT SDK via
`settings.php`.

One of the exporter libraries is required in order to send telemetry data to an
OpenTelemetry endpoint.

- [OpenTelemetry Registry](https://opentelemetry.io/ecosystem/registry/?language=php&component=exporter)


## Installation

Install as you would normally install a contributed Drupal module. For further information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

Add one or more of the recommended libraries using `composer`.


## Configuration

1. Enable the module at Administration > Extend.
1. Either setup Zero-code instrumentation or SDK Autoloading and supply an
   appropriate configuration.


## Maintainers

- [znerol](https://www.drupal.org/u/znerol)
