<?php

declare(strict_types=1);

namespace Drupal\Tests\otlrs;

use OpenTelemetry\API\Trace\Span;
use OpenTelemetry\API\Trace\SpanContextInterface;
use OpenTelemetry\API\Trace\SpanInterface;

/**
 * Introspectable span.
 */
class IntrospectableSpan extends Span {

  /**
   * Span name.
   */
  private string $name = '';

  /**
   * Span attributes.
   *
   * @var array<string, bool|int|float|string|array|null>
   */
  private array $attributes = [];

  /**
   * Recorded exception.
   */
  private ?\Throwable $exception = NULL;

  /**
   * {@inheritdoc}
   */
  public function getContext(): SpanContextInterface {
    throw new \BadMethodCallException('Method not implemented');
  }

  /**
   * {@inheritdoc}
   */
  public function isRecording(): bool {
    throw new \BadMethodCallException('Method not implemented');
  }

  /**
   * {@inheritdoc}
   */
  public function setAttribute(string $key, bool|int|float|string|array|null $value): SpanInterface {
    if ($value !== NULL) {
      $this->attributes[$key] = $value;
    }
    else {
      unset($this->attributes[$key]);
    }
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setAttributes(iterable $attributes): SpanInterface {
    foreach ($attributes as $key => $value) {
      $this->setAttribute($key, $value);
    }
    return $this;
  }

  /**
   * Returns the attributes.
   */
  public function getAttributes(): array {
    return $this->attributes;
  }

  /**
   * {@inheritdoc}
   */
  public function addLink(SpanContextInterface $context, iterable $attributes = []): SpanInterface {
    throw new \BadMethodCallException('Method not implemented');
  }

  /**
   * {@inheritdoc}
   */
  public function addEvent(string $name, iterable $attributes = [], ?int $timestamp = NULL): SpanInterface {
    throw new \BadMethodCallException('Method not implemented');
  }

  /**
   * {@inheritdoc}
   */
  public function recordException(\Throwable $exception, iterable $attributes = []): SpanInterface {
    if (!empty($attributes)) {
      throw new \BadMethodCallException('Parameter attributes not implemented');
    }
    $this->exception = $exception;
    return $this;
  }

  /**
   * Returns recorded exception.
   */
  public function getException(): ?\Throwable {
    return $this->exception;
  }

  /**
   * {@inheritdoc}
   */
  public function updateName(string $name): SpanInterface {
    $this->name = $name;
    return $this;
  }

  /**
   * Returns the span name.
   */
  public function getName(): string {
    return $this->name;
  }

  /**
   * {@inheritdoc}
   */
  public function setStatus(string $code, ?string $description = NULL): SpanInterface {
    throw new \BadMethodCallException('Method not implemented');
  }

  /**
   * {@inheritdoc}
   */
  public function end(?int $endEpochNanos = NULL): void {
    throw new \BadMethodCallException('Method not implemented');
  }

}
