<?php

declare(strict_types=1);

namespace Drupal\Tests\otlrs\Traits;

use Drupal\Tests\otlrs\IntrospectableSpan;

/**
 * Assertions to simplify span introspection.
 */
trait SpanAssertionsTrait {

  /**
   * Asserts that a span contains the given attribute key-value pairs.
   *
   * @param \Drupal\Tests\otlrs\IntrospectableSpan $span
   *   An introspectable span.
   * @param array<string, mixed> $attributes
   *   Expected attributes.
   */
  final public static function assertSpanContainsAttributePairs(IntrospectableSpan $span, array $attributes): void {
    $spanAttributes = $span->getAttributes();
    foreach ($attributes as $key => $value) {
      static::assertArrayHasKey($key, $spanAttributes);
      static::assertEquals($value, $spanAttributes[$key]);
    }
  }

  /**
   * Asserts that a span contains the given attribute key-value pairs.
   *
   * @param \Drupal\Tests\otlrs\IntrospectableSpan $span
   *   An introspectable span.
   * @param string[] $attributeKeys
   *   List of attribute keys to check.
   */
  final public static function assertSpanNotContainsAttributeKeys(IntrospectableSpan $span, array $attributeKeys) {
    $spanAttributes = $span->getAttributes();
    foreach ($attributeKeys as $key) {
      static::assertArrayNotHasKey($key, $spanAttributes);
    }
  }

}
